style "panel-icons"
{
        stock ["panel-run"] =           {{"stock_run.png"}}
        stock ["panel-searchtool"] =    {{"stock_searchtool.png"}}
        stock ["panel-screenshot"] =    {{"stock_screenshot.png"}}
        stock ["panel-lockscreen"] =    {{"stock_lockscreen.png"}}
        stock ["panel-logout"] =        {{"stock_logout.png"}}
        stock ["panel-gnome-logo"] =    {{"stock_gnome-logo.png"}}

        stock ["panel-cde"] =           {{"stock_cde-menu.png"}}
#TBD    stock ["panel-debian"] =        {{""}}
#TBD    stock ["panel-kde"] =           {{""}}
#TBD    stock ["panel-suse"] =          {{""}}

	stock ["panel-amusements"] =    {{"stock_amusements.png"}}
	stock ["panel-accessories"] =   {{"stock_accessories.png"}}
        stock ["panel-multimedia"] =    {{"stock_multimedia.png"}}

        stock ["panel-internet"] =      {{"stock_internet.png"}}
        stock ["panel-utility"] =       {{"stock_gnome-util.png"}}

#        stock ["panel-corner-type"] =   {{"stock_corner-panel.png"}}
#        stock ["panel-edge-type"] =     {{"stock_edge-panel.png"}}
#        stock ["panel-floating-type"] = {{"stock_floating-panel.png"}}
#        stock ["panel-sliding-type"] =  {{"stock_sliding-panel.png"}}
#        stock ["panel-menu-type"] =     {{"stock_menu-panel.png"}}

        stock ["panel-launcher"] =      {{"stock_launcher-program.png"}}

        stock ["panel-drawer"] =        {{"stock_drawer.png"}}
#       stock ["panel-applet"] =        {{""}}
#       stock ["panel-desktop"] =       {{""}}

#	stock ["panel-arrow-left"] =	{{"stock_panel_hide_left.png"}}
#	stock ["panel-arrow-right"] =	{{"stock_panel_hide_right.png"}}
#	stock ["panel-arrow-up"] =	{{"stock_panel_hide_up.png"}}
#	stock ["panel-arrow-down"] =	{{"stock_panel_hide_down.png"}}

	stock ["commandline-browser"] =	{{"stock_commandline-browser.xpm"}}
	stock ["commandline-history"] =	{{"stock_commandline-history.xpm"}}

}
class "GtkWidget" style "panel-icons"
