
  stock["gnome-stock-about"] = {{ "stock_about.png" }}
  stock["gnome-stock-volume"] = {{ "stock_volume.png" }}
  stock["gnome-stock-mic"] = {{ "stock_mic.png" }}
  stock["gnome-stock-line-in"] = {{ "stock_line-in.png" }}
  stock["gnome-stock-attach"] = {{ "stock_attach.png" }}
  stock["gnome-stock-book-blue"] = {{ "stock_book.png" }}
  stock["gnome-stock-book-green"] = {{ "stock_book.png" }}
  stock["gnome-stock-book-red"] = {{ "stock_book.png" }}
  stock["gnome-stock-book-yellow"] = {{ "stock_book.png" }}

  stock["gtk-dialog-info"] =   {{ "stock_dialog_info.png" }}
  stock["gtk-dialog-question"] = {{ "stock_dialog_question.png" }}
  stock["gtk-dialog-error"] =  {{ "stock_dialog_error.png" }}
  stock["gtk-dialog-warning"] =  {{ "stock_dialog_warning.png" }}
  stock["gtk-dialog-authentication"] =  {{ "stock_lockscreen.png" }}

  stock["gtk-dnd"] = {{ "stock_dnd.png" }} 
  stock["gtk-dnd-multiple"] = {{ "stock_dnd_multiple.png" }} 

  stock["gtk-about"] =         {{ "stock_about.png" }}
  stock["gtk-add"] =	       {{ "stock_add.png" }}
  stock["gtk-apply"] =	       {{ "stock_apply.png" }}
  stock["gtk-bold"] =	       {{ "stock_bold.png" }} 
  stock["gtk-cancel"] =	       {{ "stock_cancel.png" }}
  stock["gtk-cdrom"] =	       {{ "stock_cdrom.png" }}
  stock["gtk-clear"] =	       {{ "stock_clear.png" }}
  stock["gtk-close"] =	       {{ "stock_close.png" }}
  stock["gtk-connect"] =       {{ "stock_connect.png" }}
  stock["gtk-convert"] =       {{ "stock_convert.png" }}
  stock["gtk-copy"] =	       {{ "stock_copy.png" }}
  stock["gtk-cut"] =	       {{ "stock_cut.png" }}
  stock["gtk-delete"] =	       {{ "stock_delete.png" }}
  stock["gtk-disconnect"] =    {{ "stock_disconnect.png" }}
  stock["gtk-directory"] =     {{ "stock_open.png" }}
  stock["gtk-edit"] =          {{ "stock_edit.png" }}
  stock["gtk-execute"] =       {{ "stock_execute.png" }}
  stock["gtk-find"] =	       {{ "stock_find.png" }}
  stock["gtk-find-and-replace"] = {{ "stock_find-and-replace.png" }}
  stock["gtk-floppy"] =		{{ "stock_floppy.png" }}
  stock["gtk-goto-bottom"] =	{{ "stock_goto-bottom.png" }}
  stock["gtk-goto-first"] =	{{ "stock_goto-first.png" }}
  stock["gtk-goto-last"] =	{{ "stock_goto-last.png" }}
  stock["gtk-goto-top"] =	{{ "stock_goto-top.png" }}
  stock["gtk-go-back"] =	{{ "stock_go-back.png" }}
  stock["gtk-go-down"] =	{{ "stock_go-down.png" }}
  stock["gtk-go-forward"] =	{{ "stock_go-forward.png" }}
  stock["gtk-go-up"] =		{{ "stock_go-up.png" }}
  stock["gtk-help"] =		{{ "stock_help.png" }}
  stock["gtk-harddisk"] =	{{ "stock_harddisk.png" }}
  stock["gtk-home"] =		{{ "stock_home.png" }}
  stock["gtk-index"] =		{{ "stock_index.png" }}
  stock["gtk-info"] =		{{ "stock_info.png" }}
  stock["gtk-italic"] =		{{ "stock_italic.png" }}

  stock["gtk-jump-to"] =	{{ "stock_jump-to.png" }}
  stock["gtk-justify-center"] =	{{ "stock_justify-center.png" }}
  stock["gtk-justify-fill"] =	{{ "stock_justify-fill.png" }}
  stock["gtk-justify-left"] =	{{ "stock_justify-left.png" }}
  stock["gtk-justify-right"] =	{{ "stock_justify-right.png" }}
  stock["gtk-missing-image"] =	{{ "stock_missing-image.png" }}
  stock["gtk-media-forward"] =  {{ "media-forward.png" }}
  stock["gtk-media-next"] =     {{ "media-next.png" }}
  stock["gtk-media-pause"] =    {{ "media-pause.png" }}
  stock["gtk-media-play"] =     {{ "media-play.png" }}
  stock["gtk-media-previous"] = {{ "media-prev.png" }}
  stock["gtk-media-record"] =   {{ "media-record.png" }}
  stock["gtk-media-rewind"] =   {{ "media-backward.png" }}
  stock["gtk-media-stop"] =     {{ "media-stop.png" }}
  stock["gtk-new"] =	     	{{ "stock_new.png" }}
  stock["gtk-no"] =		{{ "stock_no.png" }} 
  stock["gtk-ok"] =		{{ "stock_ok.png" }}
  stock["gtk-open"] =		{{ "stock_open.png" }} 
  stock["gtk-paste"] =		{{ "stock_paste.png" }}
  stock["gtk-print"] =		{{ "stock_print.png" }}
  stock["gtk-print-preview"] =	{{ "stock_print-preview.png" }}
  stock["gtk-preferences"] =	{{ "stock_preferences.png" }}
  stock["gtk-properties"] =	{{ "stock_properties.png" }}
  stock["gtk-quit"] =		{{ "stock_quit.png" }}
  stock["gtk-redo"] =		{{ "stock_redo.png" }}
  stock["gtk-refresh"] =	{{ "stock_refresh.png" }}
  stock["gtk-remove"] =		{{ "stock_remove.png" }}
  stock["gtk-revert-to-saved"] ={{ "stock_revert-to-saved.png" }}
  stock["gtk-save"] =		{{ "stock_save.png" }}
  stock["gtk-save-as"] =	{{ "stock_save-as.png" }}
  stock["gtk-select-color"] =	{{ "stock_select-color.png" }}
  stock["gtk-select-font"] =	{{ "stock_select-font.png" }}
  stock["gtk-sort-ascending"] =	{{ "stock_sort-ascending.png" }}
  stock["gtk-sort-descending"] ={{ "stock_sort-descending.png" }}
  stock["gtk-spell-check"] =	{{ "stock_spell-check.png" }}
  stock["gtk-stop"] =		{{ "stock_stop.png" }}
  stock["gtk-strikethrough"] =	{{ "stock_strikethrough.png" }}
  stock["gtk-undelete"] =	{{ "stock_undelete.png" }}
  stock["gtk-underline"] =	{{ "stock_underline.png" }}
  stock["gtk-undo"] =		{{ "stock_undo.png" }}
  stock["gtk-yes"] =		{{ "stock_yes.png" }} 
  stock["gtk-zoom-100"] =	{{ "stock_zoom-100.png" }}
  stock["gtk-zoom-fit"] =	{{ "stock_zoom-fit.png" }}
  stock["gtk-zoom-in"] =	{{ "stock_zoom-in.png" }}
  stock["gtk-zoom-out"] =	{{ "stock_zoom-out.png" }}

  stock["terminal-edit"] =      {{ "stock_preferences.png" }}
  stock["session-stock-edit"] = {{ "stock_preferences.png" }}
}

class "GtkWidget" style "default"

