style "media-icons"
{

        stock ["media-stop"] =       {{"media-stop.png"}}
        stock ["media-play"] = 	{{"media-play.png"}}
        stock ["media-pause"] = 	{{"media-pause.png"}}
        stock ["media-prev"] =       {{"media-prev.png"}}
        stock ["media-next"] =       {{"media-next.png"}}
        stock ["media-eject"] =      {{"media-eject.png"}}
        stock ["media-record"] =      {{"media-record.png"}}

	stock ["volume-mute"] =      	{{"volume-mute.png"}}
        stock ["volume-zero"] =      	{{"volume-zero.png"}}
        stock ["volume-min"] =      	{{"volume-min.png"}}
        stock ["volume-med"] =      	{{"volume-medium.png"}}
        stock ["volume-max"] =      	{{"volume-max.png"}}

}
class "GtkWidget" style "media-icons"

